@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2003 Zope Corporation and Contributors.
+# Copyright (c) 2003 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,12 +12,9 @@
 #
 ##############################################################################
 """Context Tests
-
-$Id: test_decorator.py 95540 2009-01-30 09:40:45Z ctheune $
 """
 
-import unittest
-from zope.testing import doctest
+import doctest
 
 
 def test_suite():
