@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2003 Zope Corporation and Contributors.
+# Copyright (c) 2003 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -506,13 +506,6 @@ if sys.version_info >= (2, 6):
         >>> [c.__name__ for c in PBar.__mro__]
         ['Bar', 'Foo', 'MyABC', 'object']
 
-        >>> issubclass(PBar, Foo)
-        True
-
-        >>> issubclass(Bar, Foo)
-        True
-
-        >>> PBar = ProxyFactory(PBar)
         >>> check_forbidden_call(PBar)
         'ForbiddenAttribute: __call__'
         >>> check_forbidden_get(PBar, '__dict__')
@@ -542,18 +535,9 @@ if sys.version_info >= (2, 6):
         1
         >>> int(PBar.__class__ == abc.ABCMeta)
         1
-
-
-
         """
 
 
-
-from zope.testing.doctestunit import DocTestSuite
-
 def test_suite():
+    from doctest import DocTestSuite
     return DocTestSuite()
-
-if __name__ == '__main__':
-    import unittest
-    unittest.main()
